pub struct DuplicatesFinder { /* private fields */ }Implementations
Sourceimpl DuplicatesFinder
Checks if the given path is a duplicate file by detecting its
precence in the hashmap.Otherwise store the hash of the file in the hashmap
impl DuplicatesFinder
Checks if the given path is a duplicate file by detecting its precence in the hashmap.Otherwise store the hash of the file in the hashmap
Arguments
path- APathBufrepresenting the path to the file.
Returns
Returns Ok(true) if the file is a duplicate, Ok(false) otherwise.
Returns an Err if there was an error while checking for duplicates.
pub fn is_duplicate(&mut self, path: &PathBuf) -> Result<bool, ClineupError>